==> ruby_r-1.7.3.2002.09.27.tgz: lib/ruby/1.7/i386-freebsd4_r/rbconfig.rb <==

module Config

  RUBY_VERSION == "1.7.3" or
    raise "ruby lib version (1.7.3) doesn't match executable version (#{RUBY_VERSION})"

# This file was created by configrb when ruby was built. Any changes
# made to this file will be lost the next time ruby is built.
  DESTDIR = '' if not defined? DESTDIR
  CONFIG = {}
  TOPDIR = File.dirname(__FILE__).sub!(%r'/lib/ruby/1\.7/i386\-freebsd4_r\Z', '')
  CONFIG["srcdir"] = "/tmp/a/ports/lang/ruby_r-devel/work/ruby-1.7.3-2002.09.27"
  CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
  CONFIG["ruby_install_name"] = "ruby17_r"
  CONFIG["EXEEXT"] = ""
  CONFIG["SHELL"] = "/bin/sh"
  CONFIG["PATH_SEPARATOR"] = ":"
  CONFIG["PACKAGE_NAME"] = ""
  CONFIG["PACKAGE_TARNAME"] = ""
  CONFIG["PACKAGE_VERSION"] = ""
  CONFIG["PACKAGE_STRING"] = ""
  CONFIG["PACKAGE_BUGREPORT"] = ""
  CONFIG["exec_prefix"] = "$(prefix)"
  CONFIG["bindir"] = "$(exec_prefix)/bin"
  CONFIG["sbindir"] = "$(exec_prefix)/sbin"
  CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
  CONFIG["datadir"] = "$(prefix)/share"
  CONFIG["sysconfdir"] = "$(prefix)/etc"
  CONFIG["sharedstatedir"] = "$(prefix)/com"
  CONFIG["localstatedir"] = "$(prefix)/var"
  CONFIG["libdir"] = "$(exec_prefix)/lib"
  CONFIG["includedir"] = "$(prefix)/include"
  CONFIG["oldincludedir"] = "/usr/include"
  CONFIG["infodir"] = "$(prefix)/info"
  CONFIG["mandir"] = "$(prefix)/man"
  CONFIG["build_alias"] = ""
  CONFIG["host_alias"] = ""
  CONFIG["target_alias"] = "i386-freebsd4_r"
  CONFIG["ECHO_C"] = ""
  CONFIG["ECHO_N"] = "-n"
  CONFIG["ECHO_T"] = ""
  CONFIG["LIBS"] = "-lcrypt -lm "
  CONFIG["MAJOR"] = "1"
  CONFIG["MINOR"] = "7"
  CONFIG["TEENY"] = "3"
  CONFIG["build"] = "i386-unknown-freebsd4.7"
  CONFIG["build_cpu"] = "i386"
  CONFIG["build_vendor"] = "unknown"
  CONFIG["build_os"] = "freebsd4.7"
  CONFIG["host"] = "i386-unknown-freebsd4.7"
  CONFIG["host_cpu"] = "i386"
  CONFIG["host_vendor"] = "unknown"
  CONFIG["host_os"] = "freebsd4.7"
  CONFIG["target"] = "i386-pc-freebsd4_r"
  CONFIG["target_cpu"] = "i386"
  CONFIG["target_vendor"] = "pc"
  CONFIG["target_os"] = "freebsd4_r"
  CONFIG["CC"] = "cc"
  CONFIG["ac_ct_CC"] = "cc"
  CONFIG["CFLAGS"] = "-D_THREAD_SAFE -O -pipe  -fPIC"
  CONFIG["LDFLAGS"] = "-rdynamic"
  CONFIG["CPPFLAGS"] = ""
  CONFIG["OBJEXT"] = "o"
  CONFIG["CPP"] = "cc -E"
  CONFIG["CPPOUTFILE"] = "-o conftest.i"
  CONFIG["OUTFLAG"] = "-o "
  CONFIG["YACC"] = "byacc"
  CONFIG["RANLIB"] = "ranlib"
  CONFIG["ac_ct_RANLIB"] = "ranlib"
  CONFIG["AR"] = "ar"
  CONFIG["ac_ct_AR"] = "ar"
  CONFIG["NM"] = ""
  CONFIG["ac_ct_NM"] = ""
  CONFIG["WINDRES"] = ""
  CONFIG["ac_ct_WINDRES"] = ""
  CONFIG["DLLWRAP"] = ""
  CONFIG["ac_ct_DLLWRAP"] = ""
  CONFIG["LN_S"] = "ln -s"
  CONFIG["SET_MAKE"] = ""
  CONFIG["LIBOBJS"] = ""
  CONFIG["ALLOCA"] = ""
  CONFIG["XLDFLAGS"] = ""
  CONFIG["DLDFLAGS"] = "-Wl,-soname,$(.TARGET)"
  CONFIG["STATIC"] = ""
  CONFIG["CCDLFLAGS"] = "-fPIC"
  CONFIG["LDSHARED"] = "cc -shared"
  CONFIG["DLEXT"] = "so"
  CONFIG["DLEXT2"] = ""
  CONFIG["STRIP"] = "strip"
  CONFIG["EXTSTATIC"] = ""
  CONFIG["setup"] = "Setup"
  CONFIG["MINIRUBY"] = "./miniruby$(EXEEXT)"
  CONFIG["PREP"] = ""
  CONFIG["LIBRUBY_LDSHARED"] = "cc -shared"
  CONFIG["LIBRUBY_DLDFLAGS"] = "-Wl,-soname,$(.TARGET)"
  CONFIG["RUBY_INSTALL_NAME"] = "ruby17_r"
  CONFIG["RUBY_SO_NAME"] = ""
  CONFIG["LIBRUBY_A"] = "lib$(RUBY_INSTALL_NAME).a"
  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_INSTALL_NAME).so.$(MAJOR)$(MINOR)"
  CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_INSTALL_NAME).so"
  CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
  CONFIG["LIBRUBYARG"] = "-L. -l$(RUBY_INSTALL_NAME)"
  CONFIG["SOLIBS"] = "$(LIBS)"
  CONFIG["DLDLIBS"] = "-lc"
  CONFIG["ENABLE_SHARED"] = "yes"
  CONFIG["MAINLIBS"] = "-pthread "
  CONFIG["arch"] = "i386-freebsd4_r"
  CONFIG["sitearch"] = "i386-freebsd4_r"
  CONFIG["sitedir"] = "$(prefix)/lib/ruby/site_ruby"
  CONFIG["configure_args"] = "'--target=i386-freebsd4_r' '--program-prefix=' '--with-libc_r=yes' '--program-suffix=17_r' '--enable-shared' '--enable-ipv6' '--prefix=/usr/local' 'CFLAGS=-O -pipe ' 'target_alias=i386-freebsd4_r' 'CC=cc'"
  CONFIG["abs_srcdir"] = "$(ac_abs_srcdir)"
  CONFIG["abs_top_srcdir"] = "$(ac_abs_top_srcdir)"
  CONFIG["builddir"] = "$(ac_builddir)"
  CONFIG["abs_builddir"] = "$(ac_abs_builddir)"
  CONFIG["top_builddir"] = "$(ac_top_builddir)"
  CONFIG["abs_top_builddir"] = "$(ac_abs_top_builddir)"
  CONFIG["ruby_version"] = "$(MAJOR).$(MINOR)"
  CONFIG["rubylibdir"] = "$(libdir)/ruby/$(ruby_version)"
  CONFIG["archdir"] = "$(rubylibdir)/$(arch)"
  CONFIG["sitelibdir"] = "$(sitedir)/$(ruby_version)"
  CONFIG["sitearchdir"] = "$(sitelibdir)/$(sitearch)"
  CONFIG["compile_dir"] = "/tmp/a/ports/lang/ruby_r-devel/work/ruby-1.7.3-2002.09.27"
  MAKEFILE_CONFIG = {}
  CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
  def Config::expand(val)
    val.gsub!(/\$\(([^()]+)\)|\$\{([^{}]+)\}/) do |var|
      if key = CONFIG[$1 || $2]
        Config::expand(key)
      else
	var
      end
    end
    val
  end
  CONFIG.each_value do |val|
    Config::expand(val)
  end
end

==> ruby_r-1.8.0.2003.09.09.tgz: lib/ruby/1.8/i386-freebsd4_r/rbconfig.rb <==

# This file was created by mkconfig.rb when ruby was built.  Any
# changes made to this file will be lost the next time ruby is built.

module Config
  RUBY_VERSION == "1.8.0" or
    raise "ruby lib version (1.8.0) doesn't match executable version (#{RUBY_VERSION})"

  TOPDIR = File.dirname(__FILE__).sub!(%r'/lib/ruby/1\.8/i386\-freebsd4_r\Z', '')
  DESTDIR = '' unless defined? DESTDIR
  CONFIG = {}
  CONFIG["DESTDIR"] = DESTDIR
  CONFIG["srcdir"] = "/tmp/a/ports/lang/ruby18_r/work/ruby-1.8.0"
  CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
  CONFIG["ruby_install_name"] = "ruby18_r"
  CONFIG["EXEEXT"] = ""
  CONFIG["SHELL"] = "/bin/sh"
  CONFIG["PATH_SEPARATOR"] = ":"
  CONFIG["PACKAGE_NAME"] = ""
  CONFIG["PACKAGE_TARNAME"] = ""
  CONFIG["PACKAGE_VERSION"] = ""
  CONFIG["PACKAGE_STRING"] = ""
  CONFIG["PACKAGE_BUGREPORT"] = ""
  CONFIG["exec_prefix"] = "$(prefix)"
  CONFIG["bindir"] = "$(exec_prefix)/bin"
  CONFIG["sbindir"] = "$(exec_prefix)/sbin"
  CONFIG["libexecdir"] = "$(exec_prefix)/libexec"
  CONFIG["datadir"] = "$(prefix)/share"
  CONFIG["sysconfdir"] = "$(prefix)/etc"
  CONFIG["sharedstatedir"] = "$(prefix)/com"
  CONFIG["localstatedir"] = "$(prefix)/var"
  CONFIG["libdir"] = "$(exec_prefix)/lib"
  CONFIG["includedir"] = "$(prefix)/include"
  CONFIG["oldincludedir"] = "/usr/include"
  CONFIG["infodir"] = "$(prefix)/info"
  CONFIG["mandir"] = "$(prefix)/man"
  CONFIG["build_alias"] = ""
  CONFIG["host_alias"] = ""
  CONFIG["target_alias"] = "i386-freebsd4_r"
  CONFIG["ECHO_C"] = ""
  CONFIG["ECHO_N"] = "-n"
  CONFIG["ECHO_T"] = ""
  CONFIG["LIBS"] = "-lcrypt -lm "
  CONFIG["MAJOR"] = "1"
  CONFIG["MINOR"] = "8"
  CONFIG["TEENY"] = "0"
  CONFIG["build"] = "i386-unknown-freebsd4.9"
  CONFIG["build_cpu"] = "i386"
  CONFIG["build_vendor"] = "unknown"
  CONFIG["build_os"] = "freebsd4.9"
  CONFIG["host"] = "i386-unknown-freebsd4.9"
  CONFIG["host_cpu"] = "i386"
  CONFIG["host_vendor"] = "unknown"
  CONFIG["host_os"] = "freebsd4.9"
  CONFIG["target"] = "i386-pc-freebsd4_r"
  CONFIG["target_cpu"] = "i386"
  CONFIG["target_vendor"] = "pc"
  CONFIG["target_os"] = "freebsd4_r"
  CONFIG["CC"] = "cc"
  CONFIG["ac_ct_CC"] = "cc"
  CONFIG["CFLAGS"] = "-D_THREAD_SAFE -O -pipe  -fPIC"
  CONFIG["LDFLAGS"] = "-rdynamic"
  CONFIG["CPPFLAGS"] = ""
  CONFIG["OBJEXT"] = "o"
  CONFIG["CPP"] = "cc -E"
  CONFIG["GNU_LD"] = "yes"
  CONFIG["CPPOUTFILE"] = "-o conftest.i"
  CONFIG["OUTFLAG"] = "-o "
  CONFIG["YACC"] = "byacc"
  CONFIG["RANLIB"] = "ranlib"
  CONFIG["ac_ct_RANLIB"] = "ranlib"
  CONFIG["AR"] = "ar"
  CONFIG["ac_ct_AR"] = "ar"
  CONFIG["NM"] = ""
  CONFIG["ac_ct_NM"] = ""
  CONFIG["WINDRES"] = ""
  CONFIG["ac_ct_WINDRES"] = ""
  CONFIG["DLLWRAP"] = ""
  CONFIG["ac_ct_DLLWRAP"] = ""
  CONFIG["LN_S"] = "ln -s"
  CONFIG["SET_MAKE"] = ""
  CONFIG["LIBOBJS"] = ""
  CONFIG["ALLOCA"] = ""
  CONFIG["XCFLAGS"] = ""
  CONFIG["XLDFLAGS"] = " -L."
  CONFIG["DLDFLAGS"] = "-Wl,-soname,$(.TARGET)"
  CONFIG["STATIC"] = ""
  CONFIG["CCDLFLAGS"] = "-fPIC"
  CONFIG["LDSHARED"] = "cc -shared"
  CONFIG["DLEXT"] = "so"
  CONFIG["DLEXT2"] = ""
  CONFIG["LIBEXT"] = "a"
  CONFIG["LINK_SO"] = ""
  CONFIG["LIBPATHFLAG"] = " -L%s"
  CONFIG["STRIP"] = "strip"
  CONFIG["EXTSTATIC"] = ""
  CONFIG["setup"] = "Setup"
  CONFIG["MINIRUBY"] = "./miniruby$(EXEEXT)"
  CONFIG["PREP"] = ""
  CONFIG["ARCHFILE"] = ""
  CONFIG["LIBRUBY_LDSHARED"] = "cc -shared"
  CONFIG["LIBRUBY_DLDFLAGS"] = "-Wl,-soname,$(.TARGET)"
  CONFIG["RUBY_INSTALL_NAME"] = "ruby18_r"
  CONFIG["rubyw_install_name"] = ""
  CONFIG["RUBYW_INSTALL_NAME"] = ""
  CONFIG["RUBY_SO_NAME"] = "$(RUBY_INSTALL_NAME)"
  CONFIG["LIBRUBY_A"] = "lib$(RUBY_SO_NAME)-static.a"
  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_SO_NAME).so.$(MAJOR)$(MINOR)"
  CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_SO_NAME).so"
  CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
  CONFIG["LIBRUBYARG"] = "$(LIBRUBYARG_SHARED)"
  CONFIG["LIBRUBYARG_STATIC"] = "-l$(RUBY_SO_NAME)-static"
  CONFIG["LIBRUBYARG_SHARED"] = "-l$(RUBY_SO_NAME)"
  CONFIG["SOLIBS"] = "$(LIBS)"
  CONFIG["DLDLIBS"] = "-lc"
  CONFIG["ENABLE_SHARED"] = "yes"
  CONFIG["MAINLIBS"] = "-pthread "
  CONFIG["COMMON_LIBS"] = ""
  CONFIG["COMMON_MACROS"] = ""
  CONFIG["COMMON_HEADERS"] = ""
  CONFIG["EXPORT_PREFIX"] = ""
  CONFIG["MAKEFILES"] = "Makefile"
  CONFIG["arch"] = "i386-freebsd4_r"
  CONFIG["sitearch"] = "i386-freebsd4_r"
  CONFIG["sitedir"] = "$(prefix)/lib/ruby/site_ruby"
  CONFIG["configure_args"] = "'--target=i386-freebsd4_r' '--program-prefix=' '--with-libc_r=yes' '--program-suffix=18_r' '--enable-shared' '--enable-ipv6' '--prefix=/usr/local' 'CFLAGS=-O -pipe ' 'target_alias=i386-freebsd4_r' 'CC=cc'"
  CONFIG["NROFF"] = "/usr/bin/nroff"
  CONFIG["MANTYPE"] = "doc"
  CONFIG["abs_srcdir"] = "$(ac_abs_srcdir)"
  CONFIG["abs_top_srcdir"] = "$(ac_abs_top_srcdir)"
  CONFIG["builddir"] = "$(ac_builddir)"
  CONFIG["abs_builddir"] = "$(ac_abs_builddir)"
  CONFIG["top_builddir"] = "$(ac_top_builddir)"
  CONFIG["abs_top_builddir"] = "$(ac_abs_top_builddir)"
  CONFIG["ruby_version"] = "$(MAJOR).$(MINOR)"
  CONFIG["rubylibdir"] = "$(libdir)/ruby/$(ruby_version)"
  CONFIG["archdir"] = "$(rubylibdir)/$(arch)"
  CONFIG["sitelibdir"] = "$(sitedir)/$(ruby_version)"
  CONFIG["sitearchdir"] = "$(sitelibdir)/$(sitearch)"
  CONFIG["compile_dir"] = "/tmp/a/ports/lang/ruby18_r/work/ruby-1.8.0"
  MAKEFILE_CONFIG = {}
  CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
  def Config::expand(val, config = CONFIG)
    val.gsub!(/\$\$|\$\(([^()]+)\)|\$\{([^{}]+)\}/) do |var|
      if !(v = $1 || $2)
	'$'
      elsif key = config[v]
	config[v] = false
        Config::expand(key, config)
	config[v] = key
      else
	var
      end
    end
    val
  end
  CONFIG.each_value do |val|
    Config::expand(val)
  end
end
CROSS_COMPILING = nil unless defined? CROSS_COMPILING
